@@ -4,38 +4,48 @@
 __author__ = ["fkiraly"]
 
 from sktime.datatypes._check import (
-    check_is,
     check_is_mtype,
     check_is_scitype,
     check_raise,
     mtype,
+    scitype,
 )
 from sktime.datatypes._convert import convert, convert_to
 from sktime.datatypes._examples import get_examples
 from sktime.datatypes._registry import (
+    MTYPE_LIST_HIERARCHICAL,
     MTYPE_LIST_PANEL,
+    MTYPE_LIST_PROBA,
     MTYPE_LIST_SERIES,
     MTYPE_LIST_TABLE,
     MTYPE_REGISTER,
+    SCITYPE_LIST,
     SCITYPE_REGISTER,
     mtype_to_scitype,
+    scitype_to_mtype,
 )
+from sktime.datatypes._utilities import get_cutoff
 from sktime.datatypes._vectorize import VectorizedDF
 
 __all__ = [
-    "check_is",
     "check_is_mtype",
     "check_is_scitype",
     "check_raise",
     "convert",
     "convert_to",
     "mtype",
+    "get_cutoff",
     "get_examples",
     "mtype_to_scitype",
     "MTYPE_REGISTER",
+    "MTYPE_LIST_HIERARCHICAL",
     "MTYPE_LIST_PANEL",
+    "MTYPE_LIST_PROBA",
     "MTYPE_LIST_SERIES",
     "MTYPE_LIST_TABLE",
+    "scitype",
+    "scitype_to_mtype",
+    "SCITYPE_LIST",
     "SCITYPE_REGISTER",
     "VectorizedDF",
 ]
