@@ -103,7 +103,7 @@ class AggrDist(BasePairwiseTransformerPanel):
         return distmat
 
     @classmethod
-    def get_test_params(cls):
+    def get_test_params(cls, parameter_set="default"):
         """Test parameters for AggrDist."""
         # importing inside to avoid circular dependencies
         from sktime.dists_kernels import ScipyDist
