@@ -25,12 +25,15 @@ __all__ = [
 ]
 
 import numpy as np
+import pandas as pd
 from sklearn.base import RegressorMixin, clone
 
+from sktime.datatypes._utilities import get_time_index
 from sktime.forecasting.base import ForecastingHorizon
 from sktime.forecasting.base._base import DEFAULT_ALPHA
 from sktime.forecasting.base._sktime import _BaseWindowForecaster
 from sktime.regression.base import BaseRegressor
+from sktime.utils.datetime import _shift
 from sktime.utils.validation import check_window_length
 
 
@@ -52,7 +55,7 @@ def _check_fh(fh):
 
 
 def _sliding_window_transform(
-    y, window_length, fh, X=None, scitype="tabular-regressor"
+    y, window_length, fh, X=None, transformers=None, scitype="tabular-regressor"
 ):
     """Transform time series data using sliding window.
 
@@ -69,6 +72,12 @@ def _sliding_window_transform(
         Forecasting horizon for transformed target variable
     X : pd.DataFrame, optional (default=None)
         Exogenous series.
+    transformers: *experimental*
+        A suitable transformer that allows for using an en-bloc approach with
+        make_reduction. This means that instead of using the raw past observations of
+        y across the window length, suitable features will be generated directly from
+        the past raw observations. Currently only supports WindowSummarizer to generate
+        e.g. the mean of the past 7 observations.
     scitype : str {"tabular-regressor", "time-series-regressor"}, optional
         Scitype of estimator to use with transformed data.
         - If "tabular-regressor", returns X as tabular 2d array
@@ -86,51 +95,68 @@ def _sliding_window_transform(
     # There are different ways to implement this transform. Pre-allocating an
     # array and filling it by iterating over the window length seems to be the most
     # efficient one.
-    n_timepoints = y.shape[0]
+
+    ts_index = get_time_index(y)
+    n_timepoints = ts_index.shape[0]
     window_length = check_window_length(window_length, n_timepoints)
 
-    z = _concat_y_X(y, X)
-    n_timepoints, n_variables = z.shape
+    if transformers is not None:
+        # danbartl: how to implement iteration over all transformers?
+        tf_fit = transformers[0].fit(y)
+        X_from_y = tf_fit.transform(y)
 
-    fh = _check_fh(fh)
-    fh_max = fh[-1]
+        X_from_y_cut = _cut_tail(X_from_y, n_tail=n_timepoints - tf_fit.truncate_start)
+        yt = _cut_tail(y, n_tail=n_timepoints - tf_fit.truncate_start)
 
-    if window_length + fh_max >= n_timepoints:
-        raise ValueError(
-            "The `window_length` and `fh` are incompatible with the length of `y`"
+        if X is not None:
+            X_cut = _cut_tail(X, n_tail=n_timepoints - tf_fit.truncate_start)
+            Xt = pd.concat([X_from_y_cut, X_cut], axis=1)
+        else:
+            Xt = X_from_y_cut
+    else:
+        z = _concat_y_X(y, X)
+        n_timepoints, n_variables = z.shape
+
+        fh = _check_fh(fh)
+        fh_max = fh[-1]
+
+        if window_length + fh_max >= n_timepoints:
+            raise ValueError(
+                "The `window_length` and `fh` are incompatible with the length of `y`"
+            )
+
+        # Get the effective window length accounting for the forecasting horizon.
+        effective_window_length = window_length + fh_max
+        Zt = np.zeros(
+            (
+                n_timepoints + effective_window_length,
+                n_variables,
+                effective_window_length + 1,
+            )
         )
 
-    # Get the effective window length accounting for the forecasting horizon.
-    effective_window_length = window_length + fh_max
+        # Transform data.
+        for k in range(effective_window_length + 1):
+            i = effective_window_length - k
+            j = n_timepoints + effective_window_length - k
+            Zt[i:j, :, k] = z
 
+        # Truncate data, selecting only full windows, discarding incomplete ones.
+        Zt = Zt[effective_window_length:-effective_window_length]
+
+        # Return transformed feature and target variables separately. This
+        # excludes contemporaneous values of the exogenous variables. Including them
+        # would lead to unequal-length data, with more time points for
+        # exogenous series than the target series, which is currently not supported.
+        yt = Zt[:, 0, window_length + fh]
+        Xt = Zt[:, :, :window_length]
     # Pre-allocate array for sliding windows.
-    Zt = np.zeros(
-        (
-            n_timepoints + effective_window_length,
-            n_variables,
-            effective_window_length + 1,
-        )
-    )
-
-    # Transform data.
-    for k in range(effective_window_length + 1):
-        i = effective_window_length - k
-        j = n_timepoints + effective_window_length - k
-        Zt[i:j, :, k] = z
-
-    # Truncate data, selecting only full windows, discarding incomplete ones.
-    Zt = Zt[effective_window_length:-effective_window_length]
-
-    # Return transformed feature and target variables separately. This excludes
-    # contemporaneous values of the exogenous variables. Including them would lead to
-    # unequal-length data, with more time points for exogenous series than the target
-    # series, which is currently not supported.
-    yt = Zt[:, 0, window_length + fh]
-    Xt = Zt[:, :, :window_length]
-
     # If the scitype is tabular regression, we have to convert X into a 2d array.
     if scitype == "tabular-regressor":
-        return yt, Xt.reshape(Xt.shape[0], -1)
+        if transformers is not None:
+            return yt, Xt
+        else:
+            return yt, Xt.reshape(Xt.shape[0], -1)
     else:
         return yt, Xt
 
@@ -142,8 +168,10 @@ class _Reducer(_BaseWindowForecaster):
 
     _required_parameters = ["estimator"]
 
-    def __init__(self, estimator, window_length=10):
+    def __init__(self, estimator, window_length=10, transformers=None):
         super(_Reducer, self).__init__(window_length=window_length)
+        self.transformers = transformers
+        self.transformers_ = None
         self.estimator = estimator
         self._cv = None
 
@@ -164,6 +192,41 @@ class _Reducer(_BaseWindowForecaster):
             f"implemented for {self.__class__.__name__}."
         )
 
+    @classmethod
+    def get_test_params(cls, parameter_set="default"):
+        """Return testing parameter settings for the estimator.
+
+        Parameters
+        ----------
+        parameter_set : str, default="default"
+            Name of the set of test parameters to return, for use in tests. If no
+            special parameters are defined for a value, will return `"default"` set.
+
+        Returns
+        -------
+        params : dict or list of dict, default = {}
+            Parameters to create testing instances of the class
+            Each dict are parameters to construct an "interesting" test instance, i.e.,
+            `MyClass(**params)` or `MyClass(**params[i])` creates a valid test instance.
+            `create_test_instance` uses the first (or only) dictionary in `params`
+        """
+        from sklearn.linear_model import LinearRegression
+        from sklearn.pipeline import make_pipeline
+
+        from sktime.transformations.panel.reduce import Tabularizer
+
+        # naming convention is as follows:
+        #   reducers with Tabular take an sklearn estimator, e.g., LinearRegressor
+        #   reducers with TimeSeries take an sktime supervised estimator
+        #       e.g., pipeline of Tabularizer and Linear Regression
+        # which of these is the case, we check by checking substring in the class name
+        est = LinearRegression()
+        if "TimeSeries" in cls.__name__:
+            est = make_pipeline(Tabularizer(), est)
+
+        params = {"estimator": est, "window_length": 3}
+        return params
+
 
 class _DirectReducer(_Reducer):
     strategy = "direct"
@@ -178,6 +241,7 @@ class _DirectReducer(_Reducer):
             window_length=self.window_length,
             fh=fh,
             X=X,
+            transformers=self.transformers_,
             scitype=self._estimator_scitype,
         )
 
@@ -344,9 +408,6 @@ class _MultioutputReducer(_Reducer):
 
 class _RecursiveReducer(_Reducer):
     strategy = "recursive"
-    _tags = {
-        "requires-fh-in-fit": False,  # is the forecasting horizon required in fit?
-    }
 
     def _transform(self, y, X=None):
         # For the recursive strategy, the forecasting horizon for the sliding-window
@@ -354,7 +415,12 @@ class _RecursiveReducer(_Reducer):
         # used during prediction.
         fh = ForecastingHorizon([1])
         return _sliding_window_transform(
-            y, self.window_length_, fh, X, scitype=self._estimator_scitype
+            y,
+            self.window_length_,
+            fh,
+            X=X,
+            transformers=self.transformers_,
+            scitype=self._estimator_scitype,
         )
 
     def _fit(self, y, X=None, fh=None):
@@ -373,19 +439,79 @@ class _RecursiveReducer(_Reducer):
         -------
         self : returns an instance of self.
         """
+        if self.window_length is not None and self.transformers is not None:
+            raise ValueError(
+                "Transformers provided, suggesting en-bloc approach"
+                + " to derive reduction features. Window length will be"
+                + " inferred, please set to None"
+            )
         self.window_length_ = check_window_length(
             self.window_length, n_timepoints=len(y)
         )
+        if self.transformers is not None:
+            self.transformers_ = clone(self.transformers)
+            self.transformers = clone(self.transformers)
+
+        if self.window_length is None:
+            if isinstance(self.transformers_, list):
+                truncate_start = self.transformers_[0].fit(y).truncate_start
+                self.window_length_ = truncate_start
+            else:
+                truncate_start = self.transformers_.fit(y).truncate_start
+                self.window_length_ = truncate_start
 
         yt, Xt = self._transform(y, X)
 
         # Make sure yt is 1d array to avoid DataConversion warning from scikit-learn.
-        yt = yt.ravel()
+        if self.transformers is not None:
+            yt = yt.to_numpy().ravel()
+        else:
+            yt = yt.ravel()
 
         self.estimator_ = clone(self.estimator)
         self.estimator_.fit(Xt, yt)
         return self
 
+    def _get_shifted_window(self, shift=0, y_update=None, X_update=None):
+        """Select shifted window."""
+        # Get the start and end points of the last window.
+        cutoff = _shift(self.cutoff, by=shift)
+        start = _shift(cutoff, by=-self.window_length_ + 1)
+
+        if self.transformers_ is not None:
+            # Get the last window of the endogenous variable.
+            # If X is given, also get the last window of the exogenous variables.
+            if isinstance(cutoff, pd._libs.tslibs.period.Period):
+                dateline = pd.period_range(start=start, end=cutoff)
+            elif isinstance(self.cutoff, np.int64) or isinstance(self.cutoff, int):
+                dateline = list(range(start, cutoff + 1))
+            else:
+                dateline = pd.date_range(start=start, end=cutoff)
+
+            y = _create_multiindex(dateline, self._y)
+            y.update(self._y)
+            if y_update is not None:
+                y.update(y_update)
+            # Create new X with old values and new features derived from forecasts
+            X_from_y = self.transformers_[0].fit_transform(y)
+            X_from_y_cut = _cut_tail(X_from_y)
+            if self._X is not None:
+                X = _create_multiindex(dateline, self._X)
+                X.update(self._X)
+                if X_update is not None:
+                    X.update(X_update)
+                X_cut = _cut_tail(X)
+                X = pd.concat([X_from_y_cut, X_cut], axis=1)
+            else:
+                X = X_from_y_cut
+                y = _cut_tail(y)
+        else:
+            # Get the last window of the endogenous variable.
+            y = self._y.loc[start:cutoff].to_numpy()
+            # If X is given, also get the last window of the exogenous variables.
+            X = self._X.loc[start:cutoff].to_numpy() if self._X is not None else None
+        return y, X
+
     def _predict_last_window(
         self, fh, X=None, return_pred_int=False, alpha=DEFAULT_ALPHA
     ):
@@ -395,49 +521,110 @@ class _RecursiveReducer(_Reducer):
             )
 
         # Get last window of available data.
-        y_last, X_last = self._get_last_window()
+        if self.transformers_ is not None:
+            y_last, X_last = self._get_shifted_window()
+        else:
+            y_last, X_last = self._get_last_window()
 
         # If we cannot generate a prediction from the available data, return nan.
-        if not self._is_predictable(y_last):
-            return self._predict_nan(fh)
-
-        # Pre-allocate arrays.
-        if X is None:
-            n_columns = 1
+        # danbartl: check for window_length fails since transformed data is returned.
+        if self.transformers_ is None:
+            if not self._is_predictable(y_last):
+                return self._predict_nan(fh)
         else:
-            n_columns = X.shape[1] + 1
-        window_length = self.window_length_
-        fh_max = fh.to_relative(self.cutoff)[-1]
+            ys = np.array(y_last)
+            if not np.sum(np.isnan(ys)) == 0 and np.sum(np.isinf(ys)) == 0:
+                return self._predict_nan(fh)
 
-        y_pred = np.zeros(fh_max)
-        last = np.zeros((1, n_columns, window_length + fh_max))
+        if self.transformers_ is not None:
+            fh_max = fh.to_relative(self.cutoff)[-1]
 
-        # Fill pre-allocated arrays with available data.
-        last[:, 0, :window_length] = y_last
-        if X is not None:
-            last[:, 1:, :window_length] = X_last.T
-            last[:, 1:, window_length:] = X.T
+            if isinstance(self.cutoff, pd._libs.tslibs.period.Period):
+                dateline = pd.period_range(
+                    end=fh.to_absolute(self.cutoff)[-1], periods=fh_max
+                )
+            elif isinstance(self.cutoff, np.int64) or isinstance(self.cutoff, int):
+                dateline = list(
+                    range(self.cutoff + 1, fh.to_absolute(self.cutoff)[-1] + 1)
+                )
+            else:
+                dateline = pd.date_range(
+                    end=fh.to_absolute(self.cutoff)[-1], periods=fh_max
+                )
+            y_pred = _create_multiindex(dateline, self._y)
 
-        # Recursively generate predictions by iterating over forecasting horizon.
-        for i in range(fh_max):
-            # Slice prediction window.
-            X_pred = last[:, :, i : window_length + i]
+            for i in range(fh_max):
+                # Slice prediction window.
+                # Collect inputs for predictions
+                # if isinstance(self.cutoff, pd._libs.tslibs.period.Period):
+                #     date_curr = pd.period_range(end=dateline[i], periods=1)
+                # elif isinstance(self.cutoff, np.int64):
+                #     date_curr = list(range(self.cutoff,self.cutoff+fh_max))
+                # else:
+                #     date_curr = pd.date_range(end=dateline[i], periods=1)
+                # Generate predictions.
+                y_pred_vector = self.estimator_.predict(X_last)
+                y_pred_curr = _create_multiindex(
+                    [dateline[i]], self._y, fill=y_pred_vector
+                )
+                y_pred.update(y_pred_curr)
 
-            # Reshape data into tabular array.
-            if self._estimator_scitype == "tabular-regressor":
-                X_pred = X_pred.reshape(1, -1)
+                # # Update last window with previous prediction.
+                if i + 1 != fh_max:
+                    y_last, X_last = self._get_shifted_window(
+                        y_update=y_pred, X_update=X, shift=i + 1
+                    )
 
-            # Generate predictions.
-            y_pred[i] = self.estimator_.predict(X_pred)
+        else:
+            # Pre-allocate arrays.
+            if X is None:
+                n_columns = 1
+            else:
+                n_columns = X.shape[1] + 1
+            window_length = self.window_length_
+            fh_max = fh.to_relative(self.cutoff)[-1]
 
-            # Update last window with previous prediction.
-            last[:, 0, window_length + i] = y_pred[i]
+            y_pred = np.zeros(fh_max)
+            last = np.zeros((1, n_columns, window_length + fh_max))
+
+            # Fill pre-allocated arrays with available data.
+            last[:, 0, :window_length] = y_last
+            if X is not None:
+                last[:, 1:, :window_length] = X_last.T
+                last[:, 1:, window_length:] = X.T
+
+            # Recursively generate predictions by iterating over forecasting horizon.
+            for i in range(fh_max):
+                # Slice prediction window.
+                X_pred = last[:, :, i : window_length + i]
+
+                # Reshape data into tabular array.
+                if self._estimator_scitype == "tabular-regressor":
+                    X_pred = X_pred.reshape(1, -1)
+
+                # Generate predictions.
+                y_pred[i] = self.estimator_.predict(X_pred)
+
+                # Update last window with previous prediction.
+                last[:, 0, window_length + i] = y_pred[i]
 
         # While the recursive strategy requires to generate predictions for all steps
         # until the furthest step in the forecasting horizon, we only return the
         # requested ones.
         fh_idx = fh.to_indexer(self.cutoff)
-        return y_pred[fh_idx]
+
+        if isinstance(self._y.index, pd.MultiIndex):
+            yi_grp = self._y.index.names[0:-1]
+            y_return = y_pred.groupby(yi_grp, as_index=False).nth(fh_idx.to_list())
+        elif isinstance(y_pred, pd.Series) or isinstance(y_pred, pd.DataFrame):
+            y_return = y_pred.iloc[fh_idx]
+            if hasattr(y_return.index, "freq"):
+                if y_return.index.freq != y_pred.index.freq:
+                    y_return.index.freq = None
+        else:
+            y_return = y_pred[fh_idx]
+
+        return y_return
 
 
 class _DirRecReducer(_Reducer):
@@ -614,6 +801,12 @@ class RecursiveTabularRegressionForecaster(_RecursiveReducer):
         a tabular matrix.
     """
 
+    _tags = {
+        "requires-fh-in-fit": False,  # is the forecasting horizon required in fit?
+        "y_inner_mtype": ["pd.Series", "pd-multiindex", "pd_multiindex_hier"],
+        "X_inner_mtype": ["pd.DataFrame", "pd-multiindex", "pd_multiindex_hier"],
+    }
+
     _estimator_scitype = "tabular-regressor"
 
 
@@ -689,6 +882,10 @@ class RecursiveTimeSeriesRegressionForecaster(_RecursiveReducer):
         a tabular matrix.
     """
 
+    _tags = {
+        "requires-fh-in-fit": False,  # is the forecasting horizon required in fit?
+    }
+
     _estimator_scitype = "time-series-regressor"
 
 
@@ -718,6 +915,7 @@ def make_reduction(
     strategy="recursive",
     window_length=10,
     scitype="infer",
+    transformers=None,
 ):
     """Make forecaster based on reduction to tabular or time-series regression.
 
@@ -759,7 +957,9 @@ def make_reduction(
         scitype = _infer_scitype(estimator)
 
     Forecaster = _get_forecaster(scitype, strategy)
-    return Forecaster(estimator=estimator, window_length=window_length)
+    return Forecaster(
+        estimator=estimator, window_length=window_length, transformers=transformers
+    )
 
 
 def _check_scitype(scitype):
@@ -815,3 +1015,55 @@ def _get_forecaster(scitype, strategy):
         },
     }
     return registry[scitype][strategy]
+
+
+def _create_multiindex(target_date, origin_df, fill=None):
+    """Create an empty multiindex dataframe from origin dataframe."""
+    # Collect predictions
+    oi = origin_df.index
+    if not isinstance(oi, pd.MultiIndex):
+        if isinstance(origin_df, pd.Series):
+            if fill is None:
+                template = pd.Series(np.zeros(len(target_date)), index=target_date)
+            else:
+                template = pd.Series(fill, index=target_date)
+            return template
+        else:
+            if fill is None:
+                template = pd.DataFrame(
+                    np.zeros((len(target_date), len(origin_df.columns))),
+                    index=target_date,
+                    columns=origin_df.columns.to_list(),
+                )
+            else:
+                template = pd.DataFrame(
+                    fill, index=target_date, columns=origin_df.columns.to_list()
+                )
+            return template
+
+    tsids = origin_df.index.get_level_values("instances").unique()
+    mi = pd.MultiIndex.from_product(
+        [tsids, target_date], names=["instances", "timepoints"]
+    )
+
+    if fill is None:
+        template = pd.DataFrame(
+            np.zeros((len(target_date) * len(tsids), len(origin_df.columns))),
+            index=mi,
+            columns=origin_df.columns.to_list(),
+        )
+    else:
+        template = pd.DataFrame(fill, index=mi, columns=origin_df.columns.to_list())
+
+    template = template.astype(origin_df.dtypes.to_dict())
+    return template
+
+
+def _cut_tail(X, n_tail=1):
+    """Cut input at tail, supports grouping."""
+    if isinstance(X.index, pd.MultiIndex):
+        Xi_grp = X.index.names[0:-1]
+        X = X.groupby(Xi_grp, as_index=False).tail(n_tail)
+    else:
+        X = X.tail(n_tail)
+    return X
